==> digikam-2.2.0.tar.bz2: digikam-2.2.0/core/libs/dimg/filters/bcg/bcgsettings.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2010-02-09
 * Description : BCG settings view.
 *
 * Copyright (C) 2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef BCGSETTINGS_H
#define BCGSETTINGS_H

// Local includes

#include <QWidget>

// KDE includes

#include <kconfig.h>

// Local includes

#include "digikam_export.h"
#include "bcgfilter.h"

namespace Digikam
{

class BCGSettingsPriv;

class DIGIKAM_EXPORT BCGSettings : public QWidget
{
    Q_OBJECT

public:

    BCGSettings(QWidget* parent);
    ~BCGSettings();

    BCGContainer defaultSettings() const;
    void resetToDefault();

    BCGContainer settings() const;
    void setSettings(const BCGContainer& settings);

    void readSettings(KConfigGroup& group);
    void writeSettings(KConfigGroup& group);

Q_SIGNALS:

    void signalSettingsChanged();

private:

    BCGSettingsPriv* const d;
};

}  // namespace Digikam

#endif /* BCGSETTINGS_H */

==> digikam-2.9.0.tar.bz2: digikam-2.9.0/core/libs/dimg/filters/bcg/bcgsettings.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2010-02-09
 * Description : BCG settings view.
 *
 * Copyright (C) 2010-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef BCGSETTINGS_H
#define BCGSETTINGS_H

// Local includes

#include <QWidget>

// KDE includes

#include <kconfig.h>

// Local includes

#include "digikam_export.h"
#include "bcgfilter.h"

namespace Digikam
{

class DIGIKAM_EXPORT BCGSettings : public QWidget
{
    Q_OBJECT

public:

    BCGSettings(QWidget* const parent);
    ~BCGSettings();

    BCGContainer defaultSettings() const;
    void resetToDefault();

    BCGContainer settings() const;
    void setSettings(const BCGContainer& settings);

    void readSettings(KConfigGroup& group);
    void writeSettings(KConfigGroup& group);

Q_SIGNALS:

    void signalSettingsChanged();

private:

    class BCGSettingsPriv;
    BCGSettingsPriv* const d;
};

}  // namespace Digikam

#endif /* BCGSETTINGS_H */
